tokenizer\_tools.transform package
==================================

Submodules
----------

tokenizer\_tools.transform.conllz\_to\_conll module
---------------------------------------------------

.. automodule:: tokenizer_tools.transform.conllz_to_conll
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.transform.plain\_token\_to\_conll module
---------------------------------------------------------

.. automodule:: tokenizer_tools.transform.plain_token_to_conll
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tokenizer_tools.transform
   :members:
   :undoc-members:
   :show-inheritance:
